#
# spec file for package python-ethtool
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pypi_name ethtool
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-%{pypi_name}
Version:        0.15
Release:        2.6
Summary:        Ethernet settings Python bindings
License:        GPL-2.0-only
Group:          Development/Languages/Python
URL:            https://github.com/fedora-python/%{name}
Source:         https://files.pythonhosted.org/packages/source/e/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  libnl3-devel
# needs ifconfig for tests (to check feature parity)
BuildRequires:  net-tools-deprecated
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
Python bindings for the ethtool kernel interface that allows querying and
changing of Ethernet interface settings, such as speed, port, autonegotiation, and
PCI locations.

%prep
%setup -q -n %{pypi_name}-%{version}
# No module imp in python 3.12+
rm tests/test_scripts.py

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
mkdir -p %{buildroot}%{_sbindir}
mv %{buildroot}{%{_bindir},%{_sbindir}}/pifconfig
mv %{buildroot}{%{_bindir},%{_sbindir}}/pethtool
%python_clone -a %{buildroot}%{_sbindir}/pifconfig
%python_clone -a %{buildroot}%{_sbindir}/pethtool

%check
%pyunittest_arch -v

%post
# %%python_install_alternative for %{_sbindir} binaries
%{python_expand \
  %{_sbindir}/update-alternatives --quiet --install %{_sbindir}/pifconfig  pifconfig \
     %{_sbindir}/pifconfig-%{$python_version}  %{$python_version_nodots}
  %{_sbindir}/update-alternatives --quiet --install %{_sbindir}/pethtool  pethtool \
     %{_sbindir}/pethtool-%{$python_version}  %{$python_version_nodots}
}

%postun
%python_uninstall_alternative pifconfig
%python_uninstall_alternative pethtool

%files %{python_files}
%license COPYING
%doc README.rst CHANGES.rst
%{python_sitearch}/
%python_alternative %{_sbindir}/pethtool
%python_alternative %{_sbindir}/pifconfig

%changelog
* Tue Feb 13 2024 Daniel Garcia <daniel.garcia@suse.com>
- Remove broken tests with python 3.12+
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 0.15:
  - Tests are now skipped for wireguard devices
  - pifconfig is now able to show more than one IPv4 address per interface
  - pifconfig supports interfaces with no IPv4 address
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.14:
  * Declared project as bugfix only from now on
  * Support Python 3.7
  * Fix important issues reported by static analysis
  * Fix installation on non-UTF-8 locales on Python 3.5 and 3.6
  * Added set_gso(), get_gro() and set_gro() functions
  * Added installation instructions
* Wed Nov  1 2017 mc@suse.com
- provide tools for python3 only again
* Tue Oct 17 2017 mantel@suse.de
- use update_alternatives for different python versions
* Tue Oct 17 2017 jengelh@inai.de
- Update descriptions.
* Tue Oct 17 2017 mantel@suse.de
- update to version 0.13 for python3 support
- fix build for python2 and python3
- drop obsolete patch python-ethtool.patch
* Tue Mar  1 2016 olaf@aepfle.de
- add python-ethtool.patch to fix build
* Sat Nov 29 2014 p.drouand@gmail.com
- Clean-up specfile
- Fix Group
* Fri Nov 14 2014 cbosdonnat@suse.com
- Updated to version 0.11
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Fri Jan 17 2014 mc@suse.de
- update to version 0.09
  * drop sle10.patch - we do not build this for SLES10
  * drop bug-806936_0001-pifconfig-Fix-listing-of-an-Interface.patch
    upstream fixed it too
- Make pifconfig respect interface arguments from the command line
- pifethtool: Show IPv6 address information when available
- Fix memory leaks in get_interfaces_info()
- Support devices with multiple IPv4 addresses
- Fix get_active_devices() for IPv6 only interfaces
* Mon Mar  4 2013 mc@suse.de
- fix listing single network interfaces (bnc#806936)
* Fri May 18 2012 mc@suse.de
- add patch for sle10 to remove not existing function calles
  for old libnl (bnc#763015)
* Fri Apr 20 2012 mc@suse.de
- update to version 0.7 (bnc#770389)
  * fixes several memory leaks
  * add man pages
  * other bugfixes
* Sun Apr  3 2011 mc@suse.de
- update to version 0.6
- added IPv6 support
* Wed Feb  2 2011 mc@suse.de
- fix build on RH5
* Wed Jan 28 2009 dbahi@novell.com
- Packaging for suse flavors
* Mon Aug 25 2008 acme@redhat.com
- Add get_flags method from the first python-ethtool contributor, yay
- Add pifconfig command, that mimics the ifconfig tool using the
  bindings available
* Tue Aug 19 2008 acme@redhat.com
- Expand description and summary fields, as part of the fedora
  review process.
* Mon Jun  9 2008 acme@redhat.com
- add dist to the release tag
* Mon Dec 17 2007 acme@redhat.com
- First build into MRG repo
* Mon Dec 17 2007 acme@redhat.com
- Get ethtool code from rhpl 0.212
